[Glean](README.md)

# User Guides

- [Adding Glean to your project](user/adding-glean-to-your-project/index.md)
  - [Kotlin](user/adding-glean-to-your-project/kotlin.md)
  - [Swift](user/adding-glean-to-your-project/swift.md)
  - [Python](user/adding-glean-to-your-project/python.md)
  - [Javascript](user/adding-glean-to-your-project/javascript.md)
- [Integrating Glean for project managers](user/integrating-glean-for-product-managers.md)
- [Metrics](user/metrics/adding-new-metrics.md)
    - [Adding new metrics](user/metrics/adding-new-metrics.md)
    - [Testing metrics](user/metrics/testing-metrics.md)
    - [Error reporting](user/metrics/error-reporting.md)
    - [Metrics collected by the Glean SDK](user/collected-metrics/metrics.md)
- [Pings](user/pings/index.md)
    - [Ping schedules and timings overview](user/pings/ping-schedules-and-timings.md)
    - [Baseline Ping](user/pings/baseline.md)
    - [Deletion Request Ping](user/pings/deletion_request.md)
    - [Metrics Ping](user/pings/metrics.md)
    - [Events Ping](user/pings/events.md)
    - [Custom Pings](user/pings/custom.md)
    - [Testing custom pings](user/pings/testing-custom-pings.md)
- [Debugging products using Glean](user/debugging/index.md)
    - [Glean Debug Ping View](user/debugging/debug-ping-view.md)
    - [Android](user/debugging/android.md)
    - [iOS](user/debugging/ios.md)
    - [Python](user/debugging/python.md)
# API Reference

- [YAML Registry Format](reference/yaml/index.md)
- [General API](reference/general/index.md)
    - [Initializing](reference/general/initializing.md)
    - [Toggling upload status](reference/general/toggling-upload-status.md)
    - [Annotating experiments](reference/general/experiments-api.md)
- [Metric types](reference/metrics/index.md)
    - [Boolean](reference/metrics/boolean.md)
    - [Labeled Booleans](reference/metrics/labeled_booleans.md)
    - [Counter](reference/metrics/counter.md)
    - [Labeled Counters](reference/metrics/labeled_counters.md)
    - [String](reference/metrics/string.md)
    - [Labeled Strings](reference/metrics/labeled_strings.md)
    - [String List](reference/metrics/string_list.md)
    - [Timespan](reference/metrics/timespan.md)
    - [Timing Distribution](reference/metrics/timing_distribution.md)
    - [Memory Distribution](reference/metrics/memory_distribution.md)
    - [UUID](reference/metrics/uuid.md)
    - [Datetime](reference/metrics/datetime.md)
    - [Event](reference/metrics/event.md)
    - [Custom Distribution](reference/metrics/custom_distribution.md)
    - [Quantity](reference/metrics/quantity.md)
    - [Rate](reference/metrics/rate.md)

# Language Bindings Information

- [Overview](language-bindings/index.md)
- [Android](language-bindings/android/index.md)
    - [Android build configuration options](language-bindings/android/android-build-configuration-options.md)
    - [Android offline builds](language-bindings/android/android-offline-builds.md)
    - [Instrumenting Android crashes with the Glean SDK](language-bindings/android/instrument-android-crashes-example.md)
# Appendix

- [Glossary](appendix/glossary.md)
- [Changelog](appendix/changelog/index.md)
    - [Glean SDK](appendix/changelog/sdk.md)
    - [Glean.js](appendix/changelog/js.md)
- [This Week in Glean](appendix/twig.md)
- [Contribution Guidelines](appendix/contribution-guidelines.md)
